@@ -1,6 +1,6 @@
 /*
     KMetronome - ALSA Sequencer based MIDI metronome
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -75,11 +75,13 @@ HelpWindow::HelpWindow(QWidget *parent): QMainWindow(parent)
     connect(m_zoomOut, &QAction::triggered, this, [=]{ m_textBrowser->zoomOut(); });
     connect(m_close, &QAction::triggered, this, &QWidget::close);
     connect(m_textBrowser, &QTextBrowser::sourceChanged, this, &HelpWindow::updateWindowTitle);
+    connect(m_textBrowser, &QTextBrowser::backwardAvailable, m_back, &QAction::setEnabled);
 
     m_textBrowser->setOpenExternalLinks(true);
     m_textBrowser->setSearchPaths({":/help/en",":/help", ":/"});
 
     applySettings();
+    retranslateUi();
 }
 
 void HelpWindow::updateWindowTitle()
@@ -87,22 +89,6 @@ void HelpWindow::updateWindowTitle()
     setWindowTitle(m_textBrowser->documentTitle());
 }
 
-void HelpWindow::showPage(const QString &page)
-{
-    //qDebug() << Q_FUNC_INFO << page;
-    QDir hdir(":/");
-    QFileInfo finfo(hdir, page);
-    if (finfo.exists()) {
-        m_page = page;
-    } else {
-        m_page = "help/en/index.html";
-    }
-    m_textBrowser->clear();
-    m_textBrowser->clearHistory();
-    m_textBrowser->setSource(m_page);
-    show();
-}
-
 void HelpWindow::setIcons(bool internal)
 {
     m_internalIcons = internal;
@@ -172,10 +158,18 @@ void HelpWindow::closeEvent(QCloseEvent *event)
 void HelpWindow::retranslateUi()
 {
     QString language = qobject_cast<KMetronome*>(parent())->configuredLanguage();
-    m_page = QStringLiteral("help/%1/index.html").arg(language);
-    if (isVisible()) {
-        showPage(m_page);
+    if (language == "C") {
+        language = "en";
     }
+    QString page = QStringLiteral("help/%1/index.html").arg(language);
+    QDir hdir(":/");
+    QFileInfo finfo(hdir, page);
+    if (!finfo.exists()) {
+        page = "help/en/index.html";
+    }
+    m_textBrowser->clear();
+    m_textBrowser->setSource(page);
+    m_textBrowser->clearHistory();
     updateWindowTitle();
     m_home->setText(tr("&Home"));
     m_back->setText(tr("&Back"));
