@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -82,33 +82,50 @@ static QString trQtDirectory()
 #if defined(TRANSLATIONS_EMBEDDED)
     return QLatin1String(":/");
 #else
-    return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+    #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+    #else
+        return QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+    #endif
 #endif
 }
 
 KMetronome::KMetronome(QWidget *parent) :
     QMainWindow(parent),
     m_patternMode(false),
-    m_seq(nullptr)
+    m_seq(nullptr),
+    m_trp(nullptr),
+    m_trq(nullptr),
+    m_currentLang(nullptr)
 {
     new KmetronomeAdaptor(this);
     QDBusConnection dbus = QDBusConnection::sessionBus();
     dbus.registerObject("/", this);
     dbus.registerService("net.sourceforge.kmetronome");
 
-    m_trq = new QTranslator(this);
-    QCoreApplication::installTranslator(m_trq);
-    m_trp = new QTranslator(this);
-    QCoreApplication::installTranslator(m_trp);
-    QLocale locale(configuredLanguage());
-    //qDebug() << "locale:" << locale << "path:" << trDirectory();
-    if (!m_trq->load(locale, QLatin1String("qt"), QLatin1String("_"), trQtDirectory())) {
-        qWarning() << "Failure loading Qt5 translations for" << configuredLanguage();
+    QString lang = configuredLanguage();
+    QLocale locale;
+    if (!lang.isEmpty()) {
+        locale = QLocale(lang);
     }
-    if (!m_trp->load(locale, QLatin1String("kmetronome"), QLatin1String("_"), trDirectory())) {
-        qWarning() << "Failure loading program translations for" << configuredLanguage();
+    if (locale.language() != QLocale::C && locale.language() != QLocale::English) {
+        m_trq = new QTranslator(this);
+        if (m_trq->load(locale, QLatin1String("qt"), QLatin1String("_"), trQtDirectory())) {
+            QCoreApplication::installTranslator(m_trq);
+        } else {
+            qWarning() << "Failure loading Qt5 translations for" << lang
+                       << "from" << trQtDirectory();
+            delete m_trq;
+        }
+        m_trp = new QTranslator(this);
+        if (m_trp->load(locale, QLatin1String("kmetronome"), QLatin1String("_"), trDirectory())) {
+            QCoreApplication::installTranslator(m_trp);
+        } else {
+            qWarning() << "Failure loading program translations for" << lang
+                       << "from" << trDirectory();
+            delete m_trp;
+        }
     }
-    QLocale::setDefault(locale);
 
     m_ui.setupUi(this);
     m_ui.m_exitbtn->setFocusPolicy(Qt::NoFocus);
@@ -228,8 +245,7 @@ void KMetronome::about()
 void KMetronome::help()
 {
     m_helpWindow->setIcons(m_internalIcons);
-    QString hname = QString("help/%1/index.html").arg(configuredLanguage());
-    m_helpWindow->showPage(hname);
+    m_helpWindow->show();
 }
 
 void KMetronome::saveConfiguration()
@@ -671,11 +687,10 @@ void KMetronome::display(int bar, int beat)
 
 void KMetronome::setFigure(int newValue)
 {
-    int ts_dd;
-    int x = newValue;
-    for(ts_dd = 0; x > 1; x /= 2)
-        ++ts_dd;
-    m_ui.m_figure->setCurrentIndex(ts_dd);
+    int ts_dd = m_ui.m_figure->findData(newValue);
+    if (ts_dd >= 0) {
+        m_ui.m_figure->setCurrentIndex(ts_dd);
+    }
 }
 
 void KMetronome::displayTempo(int newTempo)
@@ -741,9 +756,8 @@ QString KMetronome::configuredLanguage()
 {
     if (m_language.isEmpty()) {
         QSettings settings;
-        QString defLang = QLocale::system().name().left(2);
         settings.beginGroup("Settings");
-        m_language = settings.value("language", defLang).toString();
+        m_language = settings.value("language").toString();
         settings.endGroup();
     }
     //qDebug() << Q_FUNC_INFO << m_language;
@@ -773,10 +787,17 @@ void KMetronome::slotSwitchLanguage(QAction *action)
 void KMetronome::createLanguageMenu()
 {
     QString currentLang = configuredLanguage();
+    if (currentLang.isEmpty()) {
+        QLocale loc;
+        if (loc.language() == QLocale::C || loc.language() == QLocale::English)
+            currentLang = "C";
+        else
+            currentLang = loc.name().left(2);
+    }
     QActionGroup *languageGroup = new QActionGroup(this);
     connect(languageGroup, &QActionGroup::triggered, this, &KMetronome::slotSwitchLanguage);
     QStringList locales;
-    locales << "en";
+    locales << "C";
     QDirIterator it(trDirectory(), {"*.qm"}, QDir::NoFilter, QDirIterator::NoIteratorFlags);
     while (it.hasNext()) {
         QFileInfo f(it.next());
@@ -791,7 +812,7 @@ void KMetronome::createLanguageMenu()
     m_ui.menuLanguage->clear();
     for (const QString& loc : qAsConst(locales)) {
         QLocale qlocale(loc);
-        QString localeName = loc == "en" ? QLocale::languageToString(qlocale.language()) : qlocale.nativeLanguageName();
+        QString localeName = loc == "C" ? QLocale::languageToString(QLocale::English) : qlocale.nativeLanguageName();
         QAction *action = new QAction(localeName.section(" ", 0, 0), this);
         action->setCheckable(true);
         action->setData(loc);
@@ -838,14 +859,41 @@ void KMetronome::refreshIcons()
 
 void KMetronome::retranslateUi()
 {
-    QLocale locale(configuredLanguage());
-    if (!m_trq->load(locale, QLatin1String("qt"), QLatin1String("_"), trQtDirectory())) {
-        qWarning() << "Failure loading Qt5 translations for" << configuredLanguage();
+    QLocale locale;
+    QString lang = configuredLanguage();
+    if (!lang.isEmpty()) {
+        locale = QLocale(lang);
     }
-    if (!m_trp->load(locale, QLatin1String("kmetronome"), QLatin1String("_"), trDirectory())) {
-        qWarning() << "Failure loading program translations for" << configuredLanguage();
+    if (m_trq) {
+        QCoreApplication::removeTranslator(m_trq);
+        delete m_trq;
     }
+    if (m_trp) {
+        QCoreApplication::removeTranslator(m_trp);
+        delete m_trp;
+    }
+    if (locale.language() != QLocale::C && locale.language() != QLocale::English) {
+        m_trq = new QTranslator(this);
+        if (m_trq->load(locale, QLatin1String("qt"), QLatin1String("_"), trQtDirectory())) {
+            QCoreApplication::installTranslator(m_trq);
+        } else {
+            qWarning() << "Failure loading Qt5 translations for" << lang
+                       << "from" << trQtDirectory();
+            delete m_trq;
+        }
+        m_trp = new QTranslator(this);
+        if (m_trp->load(locale, QLatin1String("kmetronome"), QLatin1String("_"), trDirectory())) {
+            QCoreApplication::installTranslator(m_trp);
+        } else {
+            qWarning() << "Failure loading program translations for" << lang
+                       << "from" << trDirectory();
+            delete m_trp;
+        }
+    }
+    auto f = getFigure();
     m_ui.retranslateUi(this);
+    IconUtils::SetupComboFigures(m_ui.m_figure);
+    setFigure(f);
     m_seq->retranslateUi();
     m_helpWindow->retranslateUi();
     createLanguageMenu();
