@@ -1,6 +1,6 @@
 /***************************************************************************
  *   KMetronome - ALSA Sequencer based MIDI metronome                      *
- *   Copyright (C) 2005-2021 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
+ *   Copyright (C) 2005-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -44,7 +44,7 @@ public:
     void display(int, int);
     int getTempo() { return m_ui.m_tempo->value(); }
     int getBeatsBar() { return m_ui.m_beatsBar->value(); }
-    int getFigure() { return m_ui.m_figure->currentIndex(); }
+    int getFigure() { return m_ui.m_figure->currentData().toInt(); }
     void setBeatsBar(int newValue) { m_ui.m_beatsBar->setValue(newValue); }
     void setFigure(int newValue);
     void enableControls(bool e);
@@ -119,8 +119,8 @@ private:
     QString m_bank;
     QString m_program;
     QString m_language;
-    QTranslator* m_trp;
-    QTranslator* m_trq;
+    QPointer<QTranslator> m_trp;
+    QPointer<QTranslator> m_trq;
     QAction* m_currentLang;
     QString m_style;
     bool m_darkMode;
